/* mgl_zb.h is part of Math Graphic Library
 * Copyright (C) 2007 Alexey Balakin <balakin@appl.sci-nnov.ru>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public License
 * as published by the Free Software Foundation
 */
//-----------------------------------------------------------------------------
#ifndef _MGL_AB_H_
#define _MGL_AB_H_
#include "mgl.h"
#define uchar	unsigned char
//-----------------------------------------------------------------------------
/// Class implement the creation of different mathematical plots using Z-ordering
class mglGraphAB : public mglGraph
{
public:
	/// Initialize ZBuffer drawing and allocate the memory for image with size [Width x Height].
	mglGraphAB(int w=600, int h=400);
	~mglGraphAB();
	// ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~  ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
	void WriteTIFF(const char *fname,const char *descr=0,int compr=0);
	void WriteJPEG(const char *fname,const char *descr=0);
	void WritePNG(const char *fname,const char *descr=0,bool alpha=false);
	virtual void WriteEPS(const char *fname,const char *descr=0);
	int NewFrame(int id=0);
	void EndFrame();

	void Alpha(bool enable)	{UseAlpha=enable;};
	void Light(bool enable)	{UseLight=enable;};
	void Light(int n, bool enable);
	void Light(int n,mglPoint p, mglColor c=WC, float br=0.5, bool infty=true);

	void InPlot(float x1,float x2,float y1,float y2);
	void Aspect(float Ax,float Ay,float Az);
	void RotateN(float Tet,float x,float y,float z);

	virtual void Finish();
	virtual void Clf(mglColor Back=NC);
	virtual void Ball(float x,float y,float z,mglColor col=RC,float alpha=1);
	virtual void Ball(float *p,float *c);
	virtual void SetSize(int w,int h);

	void Mark(float x,float y,float z,char mark='.');
	void Puts(mglPoint p,const char *text,const char *font=0,float size=-1,char dir=0);
	float Puts(mglPoint p,mglPoint l,const char *text,char font='t',float size=-1);
	void Pen(mglColor col, char style,float width);

	void Colorbar(const char *sch=0,int where=0);
	/// Get RGB bitmap of current state image.
	uchar *GetBits(){	Finish();	return G;	};
	/// Get RGBA bitmap of current state image.
	uchar *GetRGBA(){	Finish();	return G4;	};
	/// Get width of the image
	int GetWidth()	{	return Width;	};
	/// Get height of the image
	int GetHeight()	{	return Height;	};
	// ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
protected:
	uchar *G4;			///< Final picture in RGBA format. Prepared after calling mglGraphZB::Finish().
	uchar *G;			///< Final picture in RGB format. Prepared after calling mglGraphZB::Finish().
	float CDef[4];		///< Default color
	int xPos;			///< Shifting plot in X-direction (used by PostScale() function)
	int yPos;			///< Shifting plot in Y-direction (used by PostScale() function)
	int zPos;			///< Shifting plot in depth (used by PostScale() function)
	int Width;			///< Width of the image
	int Height;			///< Height of the image
	int Depth;			///< Depth of the image
	float B[9];			///< Transformation matrix (used by PostScale() function)
	float B1[9];		///< Transformation matrix for colorbar
	unsigned PDef;		///< Pen bit mask
	float pPos;			///< Current position in pen mask
	bool UseLight;		///< Flag of using lightning
	bool nLight[10];	///< Availability of light sources
	float rLight[30];	///< Position of light sources
	float pLight[30];	///< Actual position of light sources (filled by PostScale() function)
	float aLight[10];	///< Aperture of light sources
	float bLight[10];	///< Brightness of light sources
	float cLight[30];	///< Color of light sources
	bool Finished;		///< Flag that final picture \a mglGraphZB::G is ready
	float PenWidth;		///< Pen width for further line plotting
	bool ScalePuts;		///< Enable/disable point positions scaling in puts

	/// Additionally scale points \a p (array with length 3*n) for positioning in image
	void PostScale(float *p,int n,bool full=true);
	/// Additionally scale normals \a s (array with length 3*n)
	void NormScale(float *s,int n);
	/// Set default color
	void DefColor(mglColor c, float alpha=-1);

	/// Draw line between points \a p1,\a p2 with color \a c1,\a c2 at edges
	virtual void line_plot(float *p1,float *p2,float *c1,float *c2,bool all=false);
	/// Draw triangle between points \a p0,\a p1,\a p2 with color \a c0,\a c1,\a c2 at edges
	virtual void trig_plot(float *p0,float *p1,float *p2,
					float *c0,float *c1,float *c2);
	/// Draw triangle between points \a p0,\a p1,\a p2 with color \a c0,\a c1,\a c2 at edges
	virtual void trig_plot_n(float *p0,float *p1,float *p2,
					float *c0,float *c1,float *c2,
					float *n0,float *n1,float *n2);
	/// Draw face of points \a p0,\a p1,\a p2,\a p3 with color \a c0,\a c1,\a c2,\a c3 at edges
	virtual void quad_plot(float *p0,float *p1,float *p2,float *p3,
					float *c0,float *c1,float *c2,float *c3);
	/// Draw face of points \a p0,\a p1,\a p2,\a p3 with color \a c0,\a c1,\a c2,\a c3 at edges
	virtual void quad_plot_n(float *p0,float *p1,float *p2,float *p3,
					float *c0,float *c1,float *c2,float *c3,
					float *n0,float *n1,float *n2,float *n3);
	/// Draw mark at position \a pp with style \a type
	virtual void mark_plot(float *pp, char type);
	/// Combine colors in 2 plane.
	void combine(uchar *c1,uchar *c2);	//  
	virtual void cloud_plot(int nx,int ny,int nz,float *pp,float *a,float alpha);
	//    mglGraph
	void arrow_plot(float *p1,float *p2,char st);
	void font_curve(int n,float *pp,bool *tt,int *nn,const char *text,
					const char *font,float size);
	void curv_plot(int n,float *pp,bool *tt);
	void curv_plot(int n,float *pp,bool *tt,int *nn);
	void curv_plot(int n,float *pp,float *cc,bool *tt);
	void mesh_plot(int n,int m,float *pp,float *cc,bool *tt,int how);
	void surf_plot(int n,int m,float *pp,float *cc,bool *tt);
	void axial_plot(int n,float *pp,int *nn,int np, bool wire);
	void boxs_plot(int n, int m, float *pp, mglColor *cc,
				bool *tt,float Alpha, bool line);
	void surf3_plot(int n,int m,int *kx1,int *kx2,int *ky1,int *ky2,int *kz,
							float *pp,float *cc,float *kk,float *nn,bool wire);
	void trigs_plot(int n, int *nn, int m, float *pp, float *cc, bool *tt,bool wire);
	void quads_plot(int n, float *pp, float *cc, bool *tt);
	void lines_plot(int n, float *pp, float *cc, bool *tt);
private:
	void string_curve(int f,int n,float *pp,int *nn,const char *text,float size);
};
//-----------------------------------------------------------------------------
#endif
//-----------------------------------------------------------------------------
