/* mgl_gl.h is part of Math Graphic Library
 * Copyright (C) 2007 Alexey Balakin <balakin@appl.sci-nnov.ru>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public License
 * as published by the Free Software Foundation
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
//-----------------------------------------------------------------------------
#ifndef _MGL_GL_H_
#define _MGL_GL_H_
#include <GL/gl.h>
#include "mgl.h"
//-----------------------------------------------------------------------------
/// Class implements the creation of different mathematical plots under OpenGL
class mglGraphGL : public mglGraph
{
public:
	mglGraphGL() : mglGraph()	{	tetx = tety = tetz = 0; };
	//~mglGraphGL();
	// ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~  ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
	void WriteTIFF(const char *fname,const char *descr=0,int compr=0);	//   TIFF
	void WriteJPEG(const char *fname,const char *descr=0);				//   JPEG
	void WritePNG(const char *fname,const char *descr=0,bool alpha=false);//   PNG
	void Flush() {glFlush();};		//  
	void Finish(){glFinish();};		//  
	void Alpha(bool enable);		// / 
	void Light(bool enable);		// / 
	//   
	void Light(int n,mglPoint p, mglColor c=NC, float br=0.5, bool infty=true);
	void View(float tetX,float tetY,float tetZ);//  
	void Clf(mglColor Back=NC);					//   
	void InPlot(float x1,float x2,float y1,float y2);	//  
	void Aspect(float Ax,float Ay,float Az);		//    
	void RotateN(float Tet,float x,float y,float z);	//   
	//	  ()
	void Ball(float x,float y,float z,mglColor col=RC,float alpha=1);
	void Ball(float *p,float *c);
	virtual void Puts(mglPoint p,const char *text,const char *font=0,float size=-1,char dir=0);
	//    
	void Mark(float x,float y,float z,char mark='.');
	//      
	void Colorbar(const char *sch=0,int where=0);
	// ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
protected:
	float tetx, tety, tetz;	///< rotation angle values

	void DefColor(mglColor c, float alpha=-1);
	void Pen(mglColor col, char style,float width);

	void curv_plot(int n,float *pp,bool *tt);
	void curv_plot(int n,float *pp,float *cc,bool *tt);
	void curv_plot(int n,float *pp,bool *tt,int *nn);
	void mesh_plot(int n,int m,float *pp,float *cc,bool *tt,int how);
	void surf_plot(int n,int m,float *pp,float *cc,bool *tt);
	void axial_plot(int n,float *pp,int *nn,int np, bool wire);
	void cloud_plot(int nx,int ny,int nz,float *pp,float *a,float alpha);
	void boxs_plot(int n, int m, float *pp, mglColor *cc,
				bool *tt,float Alpha, bool line);
	void surf3_plot(int n,int m,int *kx1,int *kx2, int *ky1,int *ky2,int *kz,
					float *pp,float *cc,float *kk,float *nn,bool wire);
	void quads_plot(int n, float *pp, float *cc, bool *tt);
	void trigs_plot(int n, int *nn, int m, float *pp, float *cc, bool *tt,bool wire);
	void lines_plot(int n, float *pp, float *cc, bool *tt);
	void normal(float *p1,float *p2,float *p3);
	void normal(int nx,int ny,float *pp,float *nn);
};
//-----------------------------------------------------------------------------
#endif
//-----------------------------------------------------------------------------
